#
# Copyright (C) 2014-2020 Red Hat, Inc.
#
# Cockpit is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation; either version 2.1 of the License, or
# (at your option) any later version.
#
# Cockpit is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Cockpit; If not, see <https://www.gnu.org/licenses/>.
#

#
# This file is maintained at the following location:
# https://github.com/cockpit-project/cockpit/blob/main/tools/cockpit.spec
#
# If you are editing this file in another location, changes will likely
# be clobbered the next time an automated release is done.
#
# Check first cockpit-devel@lists.fedorahosted.org
#

# earliest base that the subpackages work on; this is still required as long as
# we maintain the basic/optional split, then it can be replaced with just %{version}.
%define required_base 266

# we generally want CentOS packages to be like RHEL; special cases need to check %{centos} explicitly
%if 0%{?centos}
%define rhel %{centos}
%endif

%define _hardened_build 1

%define __lib lib

%if %{defined _pamdir}
%define pamdir %{_pamdir}
%else
%define pamdir %{_libdir}/security
%endif

Name:           cockpit
Summary:        Web Console for Linux servers

License:        LGPL-2.1-or-later
URL:            https://cockpit-project.org/

Version:        338
Release:        1.1
Source0:        cockpit-%{version}.tar.gz
Source1:        cockpit.pam
Source2:        cockpit-rpmlintrc
Source3:        cockpit-suse-theme.tar
Source4:        cockpit-no-pamoath.pam
Source5:        check_cockpit_users
Source10:       update_version.sh
Source99:       README.packaging
Source98:       package-lock.json
Source97:       node_modules.spec.inc
%include        %{_sourcedir}/node_modules.spec.inc
Patch1:         0001-selinux-allow-login-to-read-motd-file.patch
Patch2:         suse_docs.patch
Patch3:         suse-microos-branding.patch
Patch4:         css-overrides.patch
Patch5:         storage-btrfs.patch
# SLE Micro specific patches
Patch101:       hide-pcp.patch
Patch102:       0002-selinux-temporary-remove-setroubleshoot-section.patch
Patch107:       0006-totp-motd.patch
Patch108:       0007-Remove-DynamicUser-setting-as-these-conflict-with-re.patch
# For anything based on SLES 15 codebase (including Leap, SLE Micro)
Patch103:       0004-leap-gnu18-removal.patch
Patch104:       selinux_libdir.patch
Patch105:       fix-libexecdir.patch
Patch106:       packagekit-single-install.patch
Patch109:       0008-pybridge-endian-flag.patch
Patch110:       add_preexec_cockpit.patch
Patch201:       remove_rh_links.patch

%define build_all 1
%if 0%{?rhel} == 8 && 0%{?epel} == 0 && !0%{?build_all}

%if "%{name}" == "cockpit"
%define build_basic 1
%define build_optional 0
%else
%define build_basic 0
%define build_optional 1
%endif

%else
%define build_basic 1
%define build_optional 1
%endif

%if 0%{?build_optional} && 0%{?suse_version} == 0
%define build_tests 1
%endif

# Allow root login in Cockpit on RHEL 8 and lower as it also allows password login over SSH.
%if 0%{?rhel} && 0%{?rhel} <= 8
%define disallow_root 0
%else
%define disallow_root 1
%endif

%if 0%{?fedora} >= 41 || 0%{?rhel}
ExcludeArch: %{ix86}
%endif

%define enable_multihost 1
%if 0%{?fedora} >= 41 || 0%{?rhel} >= 10
%define enable_multihost 0
%endif

%if 0%{?suse_version} == 0 || 0%{?suse_version} > 1500
# Ship custom SELinux policy
%define selinuxtype targeted
%define selinux_configure_arg --enable-selinux-policy=%{selinuxtype}
%define with_selinux 1
%else
%define selinux_configure_arg --enable-selinux-policy=no
%endif

BuildRequires: gcc
BuildRequires: pkgconfig(gio-unix-2.0)
BuildRequires: pkgconfig(json-glib-1.0)
BuildRequires: pkgconfig(polkit-agent-1) >= 0.105
BuildRequires: pam-devel

BuildRequires: autoconf automake
BuildRequires: make
BuildRequires: /usr/bin/python3
BuildRequires: python3-devel
BuildRequires: gettext >= 0.21
BuildRequires: openssl-devel
BuildRequires: gnutls-devel >= 3.4.3
BuildRequires: zlib-devel
BuildRequires: pkgconfig(krb5) >= 1.11
BuildRequires: libxslt-devel
BuildRequires: glib-networking
BuildRequires: sed

BuildRequires: glib2-devel >= 2.50.0
# this is for runtimedir in the tls proxy ace21c8879
BuildRequires: pkgconfig(libsystemd) >= 235
%if 0%{?suse_version}
BuildRequires: distribution-release
BuildRequires: openssh
BuildRequires: distribution-logos
BuildRequires: wallpaper-branding
# needed for /var/lib/pcp directory ownership
BuildRequires: pcp
%else
BuildRequires: openssh-clients
BuildRequires: docbook-style-xsl
%endif
BuildRequires: krb5-server
BuildRequires: gdb

# For documentation
BuildRequires: xmlto

%if 0%{?with_selinux}
BuildRequires:  selinux-policy
BuildRequires:  selinux-policy-%{selinuxtype}
BuildRequires:  selinux-policy-devel
%endif

# for rebuilding nodejs bits
BuildRequires: npm
BuildRequires: sassc
BuildRequires: local-npm-registry

# This is the "cockpit" metapackage. It should only
# Require, Suggest or Recommend other cockpit-xxx subpackages

Requires: cockpit-bridge
Requires: cockpit-ws
Requires: cockpit-system

# Optional components
Recommends: (cockpit-storaged if udisks2)
Recommends: (cockpit-packagekit if (dnf or zypper))
Suggests: python3-pcp

%if 0%{?rhel} == 0
Recommends: (cockpit-networkmanager if NetworkManager)
# c-ostree is not in RHEL 8/9
Recommends: (cockpit-ostree if rpm-ostree)
Suggests: cockpit-selinux
%endif
%if 0%{?rhel} && 0%{?centos} == 0
Requires: subscription-manager-cockpit
%endif

BuildRequires:  python3-devel
BuildRequires:  python3-pip
%if 0%{?rhel} == 0 && !0%{?suse_version}
# All of these are only required for running pytest (which we only do on Fedora)
BuildRequires:  procps-ng
BuildRequires:  python3-pytest-asyncio
BuildRequires:  python3-pytest-timeout
%endif

%prep
%setup -q -n cockpit-%{version} -a 3
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5 -p1

%patch -P 106 -p1
%patch -P 109 -p1

# SLE Micro specific patches
%if 0%{?is_smo}
%patch -P 101 -p1
%patch -P 107 -p1
# Patches for versions lower then SLE Micro 5.5
%if 0%{?sle_version} < 150500
%patch -P 102 -p1
%endif
%endif
# For anything based on SLES 15 codebase (including Leap, SLEM)
%if 0%{?suse_version} == 1500
%patch -P 103 -p1
%patch -P 104 -p1
%patch -P 105 -p1
%patch -P 108 -p1
%else
%patch -P 107 -p1
%endif

%if 0%{?suse_version} >= 1600
%patch -P 110 -p1
%endif

%patch -P 201 -p1

%if 0%{?suse_version} > 1500
cp %SOURCE1 tools/cockpit.pam
%else
cp %SOURCE4 tools/cockpit.pam
%endif
#
local-npm-registry %{_sourcedir} install --include=dev --ignore-scripts
touch package-lock.json

%build
find node_modules -name \*.node -print -delete
touch node_modules/.stamp

exec 2>&1
PKG_NAME="Cockpit"
echo "m4_define(VERSION_NUMBER, %version)" > version.m4
autoreconf -fvi -I tools
#
%configure \
    %{?selinux_configure_arg} \
%if 0%{?suse_version}
    --docdir=%_defaultdocdir/%{name} \
    --libexecdir=%_libexecdir \
%endif
    --with-pamdir='%{pamdir}' \
%if %{enable_multihost}
    --enable-multihost \
%endif

%if 0%{?with_selinux}
make -f /usr/share/selinux/devel/Makefile cockpit.pp
bzip2 -9 cockpit.pp
%endif

%make_build

%check
make -j$(nproc) check

%if 0%{?rhel} == 0 && 0%{?suse_version} == 0
%tox
%endif

%install
# In obs we get  write error: stdout
%make_install | tee make_install.log
make install-tests DESTDIR=%{buildroot}
%if 0%{?suse_version} > 1500
mkdir -p $RPM_BUILD_ROOT%{_pam_vendordir}
install -p -m 644 tools/cockpit.pam $RPM_BUILD_ROOT%{_pam_vendordir}/cockpit
%else
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/pam.d
install -p -m 644 tools/cockpit.pam $RPM_BUILD_ROOT%{_sysconfdir}/pam.d/cockpit
%endif
rm -f %{buildroot}/%{_libdir}/cockpit/*.so
install -D -p -m 644 AUTHORS COPYING README.md %{buildroot}%{_docdir}/cockpit/

# selinux
%if 0%{?with_selinux}
install -D -m 644 %{name}.pp.bz2 %{buildroot}%{_datadir}/selinux/packages/%{selinuxtype}/%{name}.pp.bz2
install -D -m 644 -t %{buildroot}%{_mandir}/man8 selinux/%{name}_session_selinux.8cockpit
install -D -m 644 -t %{buildroot}%{_mandir}/man8 selinux/%{name}_ws_selinux.8cockpit
# create this directory in the build root so that %ghost sees the desired mode
install -d -m 700 %{buildroot}%{_sharedstatedir}/selinux/%{selinuxtype}/active/modules/200/%{name}
%endif

# SUSE branding
mkdir -p %{buildroot}%{_datadir}/cockpit/branding/suse
pushd cockpit-suse-theme
cp src/css-overrides.css %{buildroot}%{_datadir}/cockpit/branding/suse
cp src/fonts.css %{buildroot}%{_datadir}/cockpit/branding/suse
cp -a src/fonts %{buildroot}%{_datadir}/cockpit/branding/suse
popd

%if 0%{?suse_version} == 1500
sed -i -e 's#"/lib/systemd/system#"%{_unitdir}#' \
  %{buildroot}%{_datadir}/cockpit/packagekit/manifest.json
%endif

# Build the package lists for resource packages
# cockpit-bridge is the basic dependency for all cockpit-* packages, so centrally own the page directory
echo '%dir %{_datadir}/cockpit' > base.list
echo '%dir %{_datadir}/cockpit/base1' >> base.list
find %{buildroot}%{_datadir}/cockpit/base1 -type f -o -type l >> base.list
echo '%{_sysconfdir}/cockpit/machines.d' >> base.list
echo %{buildroot}%{_datadir}/polkit-1/actions/org.cockpit-project.cockpit-bridge.policy >> base.list

echo '%dir %{_datadir}/cockpit/shell' >> system.list
find %{buildroot}%{_datadir}/cockpit/shell -type f >> system.list

echo '%dir %{_datadir}/cockpit/systemd' >> system.list
find %{buildroot}%{_datadir}/cockpit/systemd -type f >> system.list

echo '%dir %{_datadir}/cockpit/users' >> system.list
find %{buildroot}%{_datadir}/cockpit/users -type f >> system.list

echo '%dir %{_datadir}/cockpit/metrics' >> system.list
find %{buildroot}%{_datadir}/cockpit/metrics -type f >> system.list

echo '%dir %{_datadir}/cockpit/kdump' > kdump.list
find %{buildroot}%{_datadir}/cockpit/kdump -type f >> kdump.list

echo '%dir %{_datadir}/cockpit/sosreport' > sosreport.list
find %{buildroot}%{_datadir}/cockpit/sosreport -type f >> sosreport.list

echo '%dir %{_datadir}/cockpit/storaged' > storaged.list
find %{buildroot}%{_datadir}/cockpit/storaged -type f >> storaged.list

echo '%dir %{_datadir}/cockpit/networkmanager' > networkmanager.list
find %{buildroot}%{_datadir}/cockpit/networkmanager -type f >> networkmanager.list

echo '%dir %{_datadir}/cockpit/packagekit' > packagekit.list
find %{buildroot}%{_datadir}/cockpit/packagekit -type f >> packagekit.list

echo '%dir %{_datadir}/cockpit/apps' >> packagekit.list
find %{buildroot}%{_datadir}/cockpit/apps -type f >> packagekit.list

echo '%dir %{_datadir}/cockpit/selinux' > selinux.list
find %{buildroot}%{_datadir}/cockpit/selinux -type f >> selinux.list

echo '%dir %{_datadir}/cockpit/static' > static.list
find %{buildroot}%{_datadir}/cockpit/static/* -type d | while read line; do echo "%dir $line"; done >> static.list
find %{buildroot}%{_datadir}/cockpit/static -type f >> static.list

# when not building basic packages, remove their files
%if 0%{?build_basic} == 0
for pkg in base1 branding motd kdump networkmanager selinux shell sosreport static systemd users metrics; do
    rm -r %{buildroot}/%{_datadir}/cockpit/$pkg
    rm -f %{buildroot}/%{_datadir}/metainfo/org.cockpit-project.cockpit-${pkg}.metainfo.xml
done
for data in doc man pixmaps polkit-1; do
    rm -r %{buildroot}/%{_datadir}/$data
done
rm -r %{buildroot}/%{_prefix}/%{__lib}/tmpfiles.d
for libexec in cockpit-askpass cockpit-session cockpit-ws cockpit-tls cockpit-wsinstance-factory cockpit-client cockpit-client.ui cockpit-desktop cockpit-certificate-helper cockpit-certificate-ensure; do
    rm -f %{buildroot}/%{_libexecdir}/$libexec
done
rm -rf %{buildroot}/%{_sysconfdir}/pam.d %{buildroot}/%{_sysconfdir}/motd.d %{buildroot}/%{_sysconfdir}/issue.d
%if 0%{?suse_version} > 1500
rm -rf %{buildroot}/%{_pam_vendordir}
%else
rm -rf %{buildroot}/%{_sysconfdir}/pam.d
%endif
rm -f %{buildroot}/%{_libdir}/security/pam_*
rm -f %{buildroot}/usr/bin/cockpit-bridge
rm -f %{buildroot}%{_libexecdir}/cockpit-ssh
rm -f %{buildroot}%{_datadir}/metainfo/cockpit.appdata.xml
rm -rf %{buildroot}%{python3_sitelib}/cockpit*
%endif

# when not building optional packages, remove their files
%if 0%{?build_optional} == 0
for pkg in apps packagekit playground storaged; do
    rm -rf %{buildroot}/%{_datadir}/cockpit/$pkg
done
# files from -storaged
rm -f %{buildroot}/%{_prefix}/share/metainfo/org.cockpit-project.cockpit-storaged.metainfo.xml
%endif

%if 0%{?build_tests} == 0
rm -rf %{buildroot}%{_datadir}/cockpit/playground
rm -f %{buildroot}/%{pamdir}/mock-pam-conv-mod.so
%endif

sed -i "s|%{buildroot}||" *.list

%if 0%{?suse_version}
# remove brandings with stale symlinks. Means they don't match
# the distro.
pushd %{buildroot}/%{_datadir}/cockpit/branding
ls --hide={default,kubernetes,opensuse,registry,suse} | xargs rm -rv
popd
# need this in SUSE as post build checks dislike stale symlinks
install -m 644 -D /dev/null %{buildroot}/run/cockpit/issue

test -e %{buildroot}/usr/share/cockpit/branding/opensuse/default-1920x1200.jpg  || install -m 644 -D /dev/null %{buildroot}/usr/share/cockpit/branding/opensuse/default-1920x1200.jpg
test -e %{buildroot}/usr/share/cockpit/branding/suse/apple-touch-icon.png  || install -m 644 -D /dev/null %{buildroot}/usr/share/cockpit/branding/suse/apple-touch-icon.png
test -e %{buildroot}/usr/share/cockpit/branding/suse/default-1920x1200.png || install -m 644 -D /dev/null %{buildroot}/usr/share/cockpit/branding/suse/default-1920x1200.png

# remove files of not installable packages
rm -r %{buildroot}%{_datadir}/cockpit/sosreport
rm -f %{buildroot}/%{_prefix}/share/metainfo/org.cockpit_project.cockpit_sosreport.metainfo.xml
rm -f %{buildroot}%{_datadir}/icons/hicolor/64x64/apps/cockpit-sosreport.png
%else
%global _debugsource_packages 1
%global _debuginfo_subpackages 0

%define find_debug_info %{_rpmconfigdir}/find-debuginfo.sh %{?_missing_build_ids_terminate_build:--strict-build-id} %{?_include_minidebuginfo:-m} %{?_find_debuginfo_dwz_opts} %{?_find_debuginfo_opts} %{?_debugsource_packages:-S debugsourcefiles.list} "%{_builddir}/%{?buildsubdir}"

%endif
# /suse_version
rm -rf %{buildroot}/usr/src/debug

# On RHEL kdump, networkmanager, selinux, and sosreport are part of the system package
%if 0%{?rhel}
cat kdump.list sosreport.list networkmanager.list selinux.list >> system.list
rm -f %{buildroot}%{_datadir}/metainfo/org.cockpit-project.cockpit-sosreport.metainfo.xml
rm -f %{buildroot}%{_datadir}/metainfo/org.cockpit-project.cockpit-kdump.metainfo.xml
rm -f %{buildroot}%{_datadir}/metainfo/org.cockpit-project.cockpit-selinux.metainfo.xml
rm -f %{buildroot}%{_datadir}/metainfo/org.cockpit-project.cockpit-networkmanager.metainfo.xml
rm -f %{buildroot}%{_datadir}/pixmaps/cockpit-sosreport.png
%endif

mkdir -p %{buildroot}%{_datadir}/cockpit/devel
cp -a pkg/lib %{buildroot}%{_datadir}/cockpit/devel

# cockpit.socket preexec to ensure users are created as dynamic users

%if 0%{?suse_version} >= 1600
install -D -m 755 %SOURCE5 %{buildroot}%{_libexecdir}/
%endif 

# -------------------------------------------------------------------------------
# Sub-packages

%description
The Cockpit Web Console enables users to administer GNU/Linux servers using a
web browser.

It offers network configuration, log inspection, diagnostic reports, SELinux
troubleshooting, interactive command-line sessions, and more.

%files
%license COPYING
%{_docdir}/cockpit/AUTHORS
%{_docdir}/cockpit/COPYING
%{_docdir}/cockpit/README.md
%{_datadir}/metainfo/org.cockpit_project.cockpit.appdata.xml
%dir %{_datadir}/icons/hicolor/128x128/apps
%dir %{_datadir}/icons/hicolor/128x128
%dir %{_datadir}/icons/hicolor
%{_datadir}/icons/hicolor/128x128/apps/cockpit.png
%doc %{_mandir}/man1/cockpit.1.gz


%package bridge
Summary: Cockpit bridge server-side component
BuildArch: noarch

%description bridge
The Cockpit bridge component installed server side and runs commands on the
system on behalf of the web based user interface.

%files bridge -f base.list
%license COPYING
%doc %{_mandir}/man1/cockpit-bridge.1.gz
%{_bindir}/cockpit-bridge
%{_libexecdir}/cockpit-askpass
%{python3_sitelib}/%{name}*

%package doc
Summary: Cockpit deployment and developer guide
BuildArch: noarch

%description doc
The Cockpit Deployment and Developer Guide shows sysadmins how to
deploy Cockpit on their machines as well as helps developers who want to
embed or extend Cockpit.

%files doc
%license COPYING
%exclude %{_docdir}/cockpit/AUTHORS
%exclude %{_docdir}/cockpit/COPYING
%exclude %{_docdir}/cockpit/README.md
%{_docdir}/cockpit

%package system
Summary: Cockpit admin interface package for configuring and troubleshooting a system
BuildArch: noarch
Requires: cockpit-bridge >= %{version}-%{release}
%if !0%{?suse_version}
Requires: shadow-utils
%endif
Requires: grep
Requires: jeos-firstboot
Requires: /usr/bin/pwscore
Requires: /usr/bin/date
Requires: (sudo or polkit)
Provides: cockpit-shell = %{version}-%{release}
Provides: cockpit-systemd = %{version}-%{release}
Provides: cockpit-tuned = %{version}-%{release}
Provides: cockpit-users = %{version}-%{release}
%if 0%{?rhel}
Requires: NetworkManager >= 1.6
Requires: sos
Requires: sudo
Recommends: PackageKit
Recommends: setroubleshoot-server >= 3.3.3
Recommends: kexec-tools
Suggests: NetworkManager-team
Suggests: python3-pcp
Provides: cockpit-kdump = %{version}-%{release}
Provides: cockpit-networkmanager = %{version}-%{release}
Provides: cockpit-selinux = %{version}-%{release}
Provides: cockpit-sosreport = %{version}-%{release}
%endif
Obsoletes: cockpit-tests <  %{version}
%if 0%{?fedora}
Recommends: (reportd if abrt)
%endif

#NPM_PROVIDES

%description system
This package contains the Cockpit shell and system configuration interfaces.

%files system -f system.list
%license COPYING
%dir %{_datadir}/cockpit/shell/images

%package ws
Summary: Cockpit Web Service
Requires: glib-networking
Requires: openssl
Requires: glib2 >= 2.50.0
%if 0%{?with_selinux}
Requires: (%{name}-ws-selinux = %{version}-%{release} if selinux-policy-base)
Requires: (selinux-policy >= %{_selinux_policy_version} if selinux-policy-%{selinuxtype})
Requires(post): (policycoreutils if selinux-policy-%{selinuxtype})
%endif
Conflicts: firewalld < 0.6.0-1
Recommends: sscg >= 2.3
Recommends: system-logos
Suggests: sssd-dbus
%if 0%{?suse_version}
Requires(pre): permissions
Requires: distribution-logos
%if 0%{?suse_version} > 1500
Requires: pam_oath >= 2.6.11.12
%endif
Requires: wallpaper-branding
%endif
# for cockpit-desktop
Suggests: python3
Obsoletes: cockpit-tests < 331
%if 0%{?suse_version} == 1500
Provides:       group(cockpit-wsinstance-socket)
Provides:       group(cockpit-session-socket)
Provides:       user(cockpit-wsinstance-socket)
Provides:       user(cockpit-session-socket)
Provides:       user(cockpit-systemd-service)
%endif

# prevent hard python3 dependency for cockpit-desktop, it falls back to other browsers
%global __requires_exclude_from ^%{_libexecdir}/cockpit-client$

%description ws
The Cockpit Web Service listens on the network, and authenticates users.

If sssd-dbus is installed, you can enable client certificate/smart card
authentication via sssd/FreeIPA.

%files ws -f static.list
%license COPYING
%doc %{_mandir}/man1/cockpit-desktop.1.gz
%doc %{_mandir}/man5/cockpit.conf.5.gz
%doc %{_mandir}/man8/cockpit-ws.8.gz
%doc %{_mandir}/man8/cockpit-tls.8.gz
%doc %{_mandir}/man8/pam_ssh_add.8.gz
%dir %{_sysconfdir}/cockpit
%config(noreplace) %{_sysconfdir}/cockpit/ws-certs.d
%if 0%{?suse_version} > 1500
%{_pam_vendordir}/cockpit
%else
%config(noreplace) %{_sysconfdir}/pam.d/cockpit
%endif
# dir is not owned by pam in openSUSE
%dir %{_sysconfdir}/motd.d
# created in %post, so that users can rm the files
%ghost %{_sysconfdir}/issue.d/cockpit.issue
%ghost %{_sysconfdir}/motd.d/cockpit
%ghost %attr(0644, root, root) %{_sysconfdir}/cockpit/disallowed-users
%ghost %dir /run/cockpit
%ghost /run/cockpit/issue
%dir %{_datadir}/cockpit/issue
%{_datadir}/cockpit/issue/update-issue
%{_datadir}/cockpit/issue/inactive.issue
%{_unitdir}/cockpit.service
%{_unitdir}/cockpit-issue.service
%{_unitdir}/cockpit.socket
%{_unitdir}/cockpit-session-socket-user.service
%{_unitdir}/cockpit-session.socket
%{_unitdir}/cockpit-session@.service
%{_unitdir}/cockpit-wsinstance-http.socket
%{_unitdir}/cockpit-wsinstance-http.service
%{_unitdir}/cockpit-wsinstance-https-factory.socket
%{_unitdir}/cockpit-wsinstance-https-factory@.service
%{_unitdir}/cockpit-wsinstance-https@.socket
%{_unitdir}/cockpit-wsinstance-https@.service
%{_unitdir}/cockpit-wsinstance-socket-user.service
%{_unitdir}/system-cockpithttps.slice
%{_prefix}/%{__lib}/tmpfiles.d/cockpit-ws.conf
%{pamdir}/pam_ssh_add.so
%{pamdir}/pam_cockpit_cert.so
%{_libexecdir}/cockpit-ws
%{_libexecdir}/cockpit-wsinstance-factory
%{_libexecdir}/cockpit-tls
%{_libexecdir}/cockpit-client
%{_libexecdir}/cockpit-client.ui
%{_libexecdir}/cockpit-desktop
%{_libexecdir}/cockpit-certificate-ensure
%{_libexecdir}/cockpit-certificate-helper
%if 0%{?suse_version} == 1500
%{?suse_version:%verify(not mode) }%attr(4750, root, cockpit-wsinstance-socket) %{_libexecdir}/cockpit-session
%else
%{_libexecdir}/check_cockpit_users
%{_libexecdir}/cockpit-session
%endif
%{_datadir}/cockpit/branding

%pre ws
%if 0%{?suse_version} == 1500
# HACK: old RPM and even Fedora's current RPM don't properly support sysusers
# https://github.com/rpm-software-management/rpm/issues/3073
getent group cockpit-wsinstance-socket >/dev/null || groupadd -r cockpit-wsinstance-socket
getent group cockpit-session-socket >/dev/null || groupadd -r cockpit-session-socket
getent passwd cockpit-wsinstance-socket >/dev/null || useradd -r -g cockpit-wsinstance-socket -d /nonexisting -s /sbin/nologin -c "User for cockpit-ws instances" cockpit-wsinstance-socket
getent passwd cockpit-session-socket >/dev/null || useradd -r -g cockpit-session-socket -d /nonexisting -s /sbin/nologin -c "User for cockpit-session instances" cockpit-session-socket
getent passwd cockpit-systemd-service >/dev/null || useradd -r -g cockpit-wsinstance-socket -d /nonexisting -s /sbin/nologin -c "User for cockpit.service" cockpit-systemd-service
%endif

%if 0%{?suse_version} > 1500
# Prepare for migration to /usr/lib; save any old .rpmsave
for i in pam.d/cockpit ; do
     test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i}.rpmsave.old ||:
done
%endif

%post ws
# set up dynamic motd/issue symlinks on first-time install; don't bring them back on upgrades if admin removed them
# disable root login on first-time install; so existing installations aren't changed
if [ "$1" = 1 ]; then
    mkdir -p /etc/motd.d /etc/issue.d
    ln -s ../../run/cockpit/issue /etc/motd.d/cockpit
    ln -s ../../run/cockpit/issue /etc/issue.d/cockpit.issue
    printf "# List of users which are not allowed to login to Cockpit\n" > /etc/cockpit/disallowed-users
    printf "root\n" >> /etc/cockpit/disallowed-users
    chmod 644 /etc/cockpit/disallowed-users
fi

if [ "$1" = 2 ]; then
    # switch old self-signed cert group from cockpit-wsintance to cockpit-ws on upgrade
    certfile=/etc/cockpit/ws-certs.d/0-self-signed.cert
    test -f $certfile && stat -c '%G' $certfile | grep -q cockpit-wsinstance && chgrp cockpit-ws $certfile

    # on upgrades, adjust motd/issue links to changed target if they still exist (changed in 331)
    if [ "$(readlink /etc/motd.d/cockpit 2>/dev/null)" = "../../run/cockpit/motd" ]; then
        ln -sfn ../../run/cockpit/issue /etc/motd.d/cockpit
    fi
    if [ "$(readlink /etc/issue.d/cockpit.issue 2>/dev/null)" = "../../run/cockpit/motd" ]; then
        ln -sfn ../../run/cockpit/issue /etc/issue.d/cockpit.issue
    fi
fi

%if 0%{?suse_version}
%set_permissions %{_libexecdir}/cockpit-session
%endif
%tmpfiles_create cockpit-ws.conf
%systemd_post cockpit.socket cockpit.service
# firewalld only partially picks up changes to its services files without this
test -f %{_bindir}/firewall-cmd && firewall-cmd --reload --quiet || true

# check for deprecated PAM config
if test -f %{_sysconfdir}/pam.d/cockpit &&  grep -q pam_cockpit_cert %{_sysconfdir}/pam.d/cockpit; then
    echo '**** WARNING:'
    echo '**** WARNING: pam_cockpit_cert is a no-op and will be removed in a'
    echo '**** WARNING: future release; remove it from your /etc/pam.d/cockpit.'
    echo '**** WARNING:'
fi

# remove obsolete system user on upgrade (replaced with DynamicUser in version 330)
if getent passwd cockpit-wsinstance >/dev/null; then
    userdel cockpit-wsinstance
fi

%preun ws
%systemd_preun cockpit.socket cockpit.service

%postun ws
%systemd_postun_with_restart cockpit.socket cockpit.service

%if 0%{?suse_version}
%verifyscript ws
%verify_permissions -e %{_libexecdir}/cockpit-session
%endif

%if 0%{?suse_version} > 1500
%posttrans ws
# Migration to /usr/lib, restore just created .rpmsave
for i in pam.d/cockpit ; do
     test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i} ||:
done
%endif

%if 0%{?with_selinux}
%package ws-selinux
Summary: SELinux security policy for cockpit-ws
# older -ws contained the SELinux policy, now split out
Conflicts: %{name}-ws < 337-1.2025
Requires(post): selinux-policy-%{selinuxtype} >= %{_selinux_policy_version}
Requires(post): libselinux-utils
Requires(post): policycoreutils
Obsoletes: %{name}-selinux-policies < 338

%description ws-selinux
SELinux policy module for the cockpit-ws package.

%files ws-selinux
%license COPYING
%{_datadir}/selinux/packages/%{selinuxtype}/%{name}.pp.bz2
%{_mandir}/man8/%{name}_session_selinux.8cockpit.*
%{_mandir}/man8/%{name}_ws_selinux.8cockpit.*
%ghost %{_sharedstatedir}/selinux/%{selinuxtype}/active/modules/200/%{name}

%posttrans ws-selinux
%selinux_relabel_pre -s %{selinuxtype}
%selinux_modules_install -s %{selinuxtype} %{_datadir}/selinux/packages/%{selinuxtype}/%{name}.pp.bz2
%selinux_relabel_post -s %{selinuxtype}

%postun ws-selinux
%selinux_modules_uninstall -s %{selinuxtype} %{name}
%selinux_relabel_post -s %{selinuxtype}
%endif

# -------------------------------------------------------------------------------
# Sub-packages that are part of cockpit-system in RHEL/CentOS, but separate in Fedora

%if 0%{?rhel} == 0

%package kdump
Summary: Cockpit user interface for kernel crash dumping
Requires: cockpit-bridge >= %{required_base}
Requires: cockpit-shell >= %{required_base}
Requires: kexec-tools
BuildArch: noarch

%description kdump
The Cockpit component for configuring kernel crash dumping.

%files kdump -f kdump.list
%license COPYING
%{_datadir}/metainfo/org.cockpit_project.cockpit_kdump.metainfo.xml

%if !0%{?suse_version}
%package sosreport
Summary: Cockpit user interface for diagnostic reports
Requires: cockpit-bridge >= %{required_base}
Requires: cockpit-shell >= %{required_base}
Requires: sos
BuildArch: noarch

%description sosreport
The Cockpit component for creating diagnostic reports with the
sosreport tool.

%files sosreport -f sosreport.list
%license COPYING
%{_datadir}/metainfo/org.cockpit_project.cockpit_sosreport.metainfo.xml
%{_datadir}/icons/hicolor/64x64/apps/cockpit-sosreport.png
%endif

%package networkmanager
Summary: Cockpit user interface for networking, using NetworkManager
Requires: cockpit-bridge >= %{required_base}
Requires: cockpit-shell >= %{required_base}
Requires: NetworkManager >= 1.6
Conflicts: cockpit-wicked
# Optional components
Recommends: NetworkManager-team
BuildArch: noarch

%description networkmanager
The Cockpit component for managing networking.  This package uses NetworkManager.

%files networkmanager -f networkmanager.list
%license COPYING
%{_datadir}/metainfo/org.cockpit_project.cockpit_networkmanager.metainfo.xml

%endif

%if 0%{?rhel} == 0 && ( 0%{?suse_version} >= 1500 || 0%{?is_smo} )

%package selinux
Summary: Cockpit SELinux package
Requires: cockpit-bridge >= %{required_base}
Requires: cockpit-shell >= %{required_base}
Requires:       policycoreutils-python-utils >= 3.1
# setroubleshoot is available on SLE Micro starting with 5.5)
%if !0%{?suse_version}  || ( 0%{?is_smo} && 0%{?sle_version} >= 150500 ) || 0%{?suse_version} >= 1600
Requires:       setroubleshoot-server >= 3.3.3
%endif
BuildArch:      noarch

%description selinux
This package contains the Cockpit user interface integration with the
utility setroubleshoot to diagnose and resolve SELinux issues.

%files selinux -f selinux.list
%license COPYING
%{_datadir}/metainfo/org.cockpit_project.cockpit_selinux.metainfo.xml

%endif

%package -n cockpit-storaged
Summary: Cockpit user interface for storage, using udisks
Requires: cockpit-shell >= %{required_base}
Requires: udisks2 >= 2.9
Requires: %{__python3}
%if 0%{?suse_version}
Requires: libudisks2-0_lvm2 >= 2.9
Requires: libudisks2-0_btrfs >= 2.9
Recommends: multipath-tools
Requires: python3-dbus-python
%else
Recommends: udisks2-lvm2 >= 2.9
Recommends: udisks2-iscsi >= 2.9
%if ! 0%{?rhel}
Recommends: udisks2-btrfs >= 2.9
%endif
Recommends: device-mapper-multipath
Recommends: clevis-luks
Requires: python3-dbus
%endif
BuildArch: noarch

%description -n cockpit-storaged
The Cockpit component for managing storage.  This package uses udisks.

%files -n cockpit-storaged -f storaged.list
%license COPYING
%{_datadir}/metainfo/org.cockpit_project.cockpit_storaged.metainfo.xml

%post storaged
# version 332 moved the btrfs temp mounts db to /run
if [ "$1" = 2 ] && [ -d /var/lib/cockpit/btrfs ]; then
    rm -rf --one-file-system  /var/lib/cockpit/btrfs || true
fi

%package devel
Summary: Development files for for Cockpit

%description devel
This package contains files used to develop cockpit modules

%files devel
%{_datadir}/cockpit/devel

%package -n cockpit-packagekit
Summary: Cockpit user interface for packages
BuildArch: noarch
Requires: cockpit-bridge >= %{required_base}
Requires: PackageKit
Recommends: python3-tracer
# HACK: https://bugzilla.redhat.com/show_bug.cgi?id=1800468
Requires: polkit

%description -n cockpit-packagekit
The Cockpit components for installing OS updates and Cockpit add-ons,
via PackageKit.

%files -n cockpit-packagekit -f packagekit.list
%license COPYING

# The changelog is automatically generated and merged
%changelog
* Fri May 23 2025 Alice Brooks <alice.brooks@suse.com>
- Update branding patch for micro and sle
* Thu May 22 2025 Alice Brooks <alice.brooks@suse.com>
- Bug fixes
- Update theme for patternfly 6
- Update spec from upstream
- Change when selinux policies are installed
* Thu May  8 2025 Luna D Dragon <luna.dragon@suse.com>
- update to 338:
    Upstream Changes:
  - Translation updates
  - Bug fixes
- Add check_cockpit_users and add_preexec_cockpit.patch to ensure manually created
  users and groups are removed. Also check systemd support is in nsswitch
* Tue Apr 29 2025 Luna D Dragon <luna.dragon@suse.com>
- Update cockpit to 337
    Upstream Changes:
    337:
  - Upgraded to Patternfly 6
  - Support dnf needs-restarting
    336.2:
  - storage: Revert "Use mdraid metadata version 1.0 when in Anaconda mode"
  - Translation updates
    336.1:
  - storage: Fix passphrase remembering with "Reuse encryption"
  - Translation updates
    336:
  - storage: Implement deletion of multi-device btrfs
  - storage: Use mdraid metadata version 1.0 when in Anaconda mode
  - Add a channel capabilities system
    335:
    storage: SMART support
- update various patches to apply on 337
* Mon Apr 28 2025 Luna D Dragon <luna.dragon@suse.com>
- Update 0007-Remove-DynamicUser-setting-as-these-conflict-with-re.patch
  Update the patch to set ProtectHome and PrivateTmp to yes as it is implied
  when DynamicUser is enabled. The patch is also now only applied on leap 15
  where it is relevant
* Wed Apr 16 2025 Alice Brooks <alice.brooks@suse.com>
- Add extra requirements for selinux policies to cockpit-selinux-policies
  so it can't be installed before selinux or policycoreutils
* Fri Apr 11 2025 Alice Brooks <alice.brooks@suse.com>
- Add a requires for either sudo or polkit for assuming admin rights
  (bsc#1240569)
* Mon Apr  7 2025 Alice Brooks <alice.brooks@suse.com>
- Ensure cockpit-selinux-policies always installs the selinux policy
  regardless of selinuxenabled status (bsc#1240787 and bsc#1240421)
* Wed Mar 19 2025 Miika Alikirri <miika.alikirri@suse.com>
- Patch python bridge to handle dbus message endianness correctly
  - added 0008-pybridge-endian-flag.patch
  (bsc#1220477)
* Wed Mar 12 2025 Luna D Dragon <luna.dragon@suse.com>
- move selinux policies to cockpit-selinux-policies bsc#1236057
* Mon Mar 10 2025 Alice Brooks <alice.brooks@suse.com>
- Update to 334.1
  - Various bug fixes and improvements
  - Translation updates
- npm modules updated, since new version
* Mon Feb 24 2025 Adam Majer <adam.majer@suse.de>
- fix build with latest local-npm-registry
* Fri Feb 21 2025 Alice Brooks <alice.brooks@suse.com>
- Always apply 0007-Remove-DynamicUser-setting-as-these-conflict-with-re.patch
  for every build system. Fixes bsc#1237451
* Thu Feb 20 2025 Miika Alikirri <miika.alikirri@suse.com>
- Add functionality to cockpit-packagekit that allows selecting what updates
  should be applied
- Added packagekit-single-install.patch file that adds this functionality
* Fri Feb  7 2025 Alice Brooks <alice.brooks@suse.com>
- Update to 332
  - Updated naming convention for motd to issue and relevant patches
- Added 0007-Remove-DynamicUser-setting-as-these-conflict-with-re.patch
  since dynamic users can't be resolved since systemd is missing in nsswitch
  bsc#1230638
* Thu Jan 30 2025 Alice Brooks <alice.brooks@suse.com>
- Remove 0005-cockpit-ws-user-remove-default-deps.patch
- Fix dynamic users for 330 since systemd isn't included in the
  nsswitch.conf
- Tidy up pam_oath removal for leap
  - Ship a new pam file since Leap15 doesn't have pam_oath
  - Don't change motd if we don't have pam_oath
- Properly fix pidfd_getpid
  - This can be dropped once we update again as it's been upstreamed
* Fri Dec  6 2024 Luna D Dragon <luna.dragon@suse.com>
- Update to 330
  - Web server: Increased sandboxing, setuid removal, bootc support
  - Development: New install mode using systemd-sysext
* Mon Nov 25 2024 Luna D Dragon <luna.dragon@suse.com>
- update to 329.1:
  - cockpit.js: Put back cockpit.{resolve,reject}() to fix subscription-manager-cockpit
- Past updates:
  * 329
  - Shell: Extra warnings when connecting to remote hosts
  * 328:
  - Bug fixes and performance improvements
  * 327:
  - Connect to similar servers without Cockpit installed
  * 326:
  - cockpit-pcp package is now obsolete
  - cockpit/ws container: Connect to servers without installed Cockpit
  - cockpit/ws container: Support host specific SSH keys
  - Storage: Support for Stratis filesystem sizes and limits
  * 325:
  - client: Properly handle unknown SSH host keys
  * 324:
  - Bug fixes and performance improvements
  * 323.1:
  - Translation updates
  * 323:
  - login: Prevent multiple logins in a single browser session
  - Update documentation links
* Wed Oct  9 2024 Alice Brooks <alice.brooks@suse.com>
- suse_docs.patch: update documentation to point at new links (bsc#1226050)
- remove_rh_links.patch: remove additional hardcoded RH refs (bsc#1221336)
- hide-pcp.patch: correct patch to properly disable pcp on micro
  (bsc#1226049)
- suse-microos-branding.patch: use suse ID as branding instead of sle-micro
  (bsc#1227441)
* Mon Sep 30 2024 Alice Brooks <alice.brooks@suse.com>
- add 0006-totp-motd.patch for guidance to enabling totp to the mtod
* Wed Sep 18 2024 Jan Zerebecki <jan.suse@zerebecki.de>
- support optional TOTP for authentication, requires pam_oath
* Tue Aug 20 2024 Adam Majer <adam.majer@suse.de>
- remove requires on pam_oath completely. It will be re-introduced
  later when it works with optional enrollment
* Tue Aug 20 2024 Alice Brooks <alice.brooks@suse.com>
- add 0005-cockpit-ws-user-remove-default-deps.patch (bsc#1229146)
* Mon Aug 12 2024 Luna D Dragon <luna.dragon@suse.com>
- new version 322:
  * shell: Deprecate host switcher
  * files: Permissions column in details view
- suse_docs.patch: refreshed
  For details, see https://cockpit-project.org/blog/cockpit-322.html
* Thu Aug  8 2024 Jan Zerebecki <jan.suse@zerebecki.de>
- revert load pam_oath, because it enforces the file for otp secrets to exist,
  will try again once pam_oath can have that optional
* Wed Aug  7 2024 Herbert Graeber <herbert@graeber-clan.de>
- fix-libexecdir.patch: Fix libexecdir for leap and sle (bsc#1223533)
- Fix systemd units folder for leap and sle (bsc#1226541)
* Wed Aug  7 2024 pallas wept <pallaswept@proton.me>
- Recommend cockpit-packagekit if zypper is installed
* Wed Aug  7 2024 Jan Zerebecki <jan.suse@zerebecki.de>
- load pam_oath for optional TOTP for authentication
* Wed Jul 31 2024 Adam Majer <adam.majer@suse.de>
- new version 321:
  * Bug fixes and performance improvements
- vendor.tar.gz: dropped. Bundling now part of main tarball.
- update_version.sh: use instead of `osc service mr` to do version
  updates. updated README.packaging
* Wed Jul  3 2024 Luna D Dragon <luna.dragon@suse.com>
- new version 320:
  * pam-ssh-add: Fix insecure killing of session ssh-agent
    (bsc#1226040, CVE-2024-6126)
- changes in older versions:
  * Storage: Btrfs snapshots
  * Podman: Add image pull action
  * Files: Bookmark support
  * webserver: System user changes
  * Metrics: Grafana setup now prefers Valkey
- 0001-users-Support-for-watching-lastlog2.patch,
  0002-users-Support-for-watching-lastlog2-and-wutmp-on-overview-page.patch
  removed, upstreamed
* Wed Jul  3 2024 Alice Brooks <alice.brooks@suse.com>
- fix suse_docs.patch causing invalid json against the storaged manifest bsc#1227299
* Thu Jun 13 2024 Luna D Dragon <luna.dragon@suse.com>
- disable selinux on leap versions without selinux
- set libexec dir to %%_libexecdir (bsc#1223533)
* Thu May 16 2024 Luna D Dragon <luna.dragon@suse.com>
- new version 316:
  * cockpit.js API: Fix format_bytes() units
- add 0001-users-Support-for-watching-lastlog2.patch (bsc#1220551)
- add 0002-users-Support-for-watching-lastlog2-and-wutmp-on-overview-page.patch (bsc#1220551)
* Wed Apr 17 2024 Adam Majer <adam.majer@suse.de>
- new version 315:
  * Networking: Show additional ports for each firewall zone
  * Networking: List Firewall active zones when unprivileged
  * Inline documentation
  * Support for transient virtual machines
  * UEFI for virtual machines
  * Unattended virtual machines installation
  * Localize times
  * Better support for various TLS certificate formats
  * Overview: Add CPU utilization to usage card
  * Dashboard: Support SSH identity unlocking when adding new machines
  * SElinux: Introduce an Ansible automation script
  * Machines: Support “bridge” type network interfaces
  * Machines: Support “bus” type disk configuration
- suse_docs.patch, storage-btrfs.patch: refreshed
* Tue Apr 16 2024 Adam Majer <adam.majer@suse.de>
- Do not require setroubleshoot in cockpit-selinux on Leap.
  It's not there
* Mon Mar  4 2024 Adam Majer <adam.majer@suse.de>
- cockpit.pam: respect /etc/cockpit/disallowed-users
  This means by default root cannot login with password to cockpit
  (bsc#1216080)
* Thu Feb 29 2024 Cathy Hu <cathy.hu@suse.com>
- Remove SELinux file context for /usr/bin/cockpit-bridge, this
  is already defined in the main selinux-policy package (bsc#1220385).
  Modified selinux_libdir.patch
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Feb 15 2024 Adam Majer <adam.majer@suse.de>
- suse-microos-branding.patch: fix branding for SLE Micro
  (bsc#1219929)
- don't clobber existing links with empty files
* Wed Jan 31 2024 Adam Majer <adam.majer@suse.de>
- new version 309:
  * storage redesign
  * initial btrfs support
  https://cockpit-project.org/blog/cockpit-309.html
* Thu Jan 25 2024 Luna D Dragon <luna.dragon@suse.com>
- suse_docs.patch: replace with suse docs and move docs with out eqiv
  to docs-rh (bsc#1219088)
- hide-docs.patch: obsolete by above, removed
* Thu Jan 25 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Provide users/groups cockpit-wsinstance and cockpit-ws: they are
  generated by cockpit-ws %%pre script.
* Wed Jan 24 2024 Adam Majer <adam.majer@suse.de>
- hide-docs.patch: hide RHEL docs in shell/manifest.json
* Fri Jan 12 2024 Adam Majer <adam.majer@suse.de>
- enable python-bridge for suse distros
- vendor.tar.gz -- submodules in vendor/ subdirectory. These are not part
  of original tarball because obs service wants to bundle node_modules
  there too....
* Thu Dec 21 2023 Adam Majer <adam.majer@suse.de> - 307
- new version 307:
  https://cockpit-project.org/blog/cockpit-307.html
  https://cockpit-project.org/blog/cockpit-306.html
  https://cockpit-project.org/blog/cockpit-305.html
  https://cockpit-project.org/blog/cockpit-304.html
  https://cockpit-project.org/blog/cockpit-303.html
  https://cockpit-project.org/blog/cockpit-302.html
  https://cockpit-project.org/blog/cockpit-301.html
- css-overrides.patch, storage-btrfs.patch: refreshed
* Wed Sep 20 2023 Miika Alikirri <miika.alikirri@suse.com>
- Port SLE selinux bug fix from SLE Micro 5.5
  * Copied selinux_libdir.patch from SLEM package
* Fri Sep  8 2023 Adam Majer <adam.majer@suse.de> - 300.1
- new version 300.1
  https://cockpit-project.org/blog/cockpit-300.html
  https://cockpit-project.org/blog/cockpit-299.html
* Fri Sep  8 2023 Adam Majer <adam.majer@suse.de>
- Re-add pwscore dependency for SLE
* Thu Aug 31 2023 Miika Alikirri <miika.alikirri@suse.com>
- Fix building for SLE15.5 and SLE15.4
* Fri Aug 18 2023 Adam Majer <adam.majer@suse.de>
- new version 298:
  https://cockpit-project.org/blog/cockpit-298.html
* Tue Aug 15 2023 Zdenek Kubala <zkubala@suse.cz>
- set setroubleshoot-server dependency and do not apply
  0002-selinux-temporary-remove-setroubleshoot-section-patch for
  cockpit-selinux when build for SLE Micro 5.5
* Thu Aug  3 2023 Adam Majer <adam.majer@suse.de>
- new version 297:
  - https://cockpit-project.org/blog/cockpit-297.html
- hide-docs.patch: refreshed
* Mon Jul 17 2023 Adam Majer <adam.majer@suse.de>
- new version 296:
  - https://cockpit-project.org/blog/cockpit-296.html
  - https://cockpit-project.org/blog/cockpit-295.html
  - https://cockpit-project.org/blog/cockpit-294.html
- 0004-leap-gnu18-removal.patch: added support for Leap thanks to Lubos
* Tue Jun 13 2023 Adam Majer <adam.majer@suse.de>
- Add fake openSUSE branding target when building on non-openSUSE
  builds so branding does not need to be removed
- Remove tests package so we don't have to ship a test PAM module
* Fri Jun  2 2023 Adam Majer <adam.majer@suse.de>
- new version 293:
  - https://cockpit-project.org/blog/cockpit-293.html
- refreshed: css-overrides.patch
* Tue May 30 2023 Adam Majer <adam.majer@suse.de>
- new version 292:
  - https://cockpit-project.org/blog/cockpit-292.html
- refreshed patches: css-overrides.patch, hide-pcp.patch,
  0001-selinux-allow-login-to-read-motd-file.patch
* Tue Feb  7 2023 Stefan Schubert <schubi@suse.com>
- Migration of PAM settings to /usr/lib/pam.d.
* Wed Jan 25 2023 Luna D Dragon <luna.dragon@suse.com>
- restore dependency on /usr/bin/pwscore (bsc#1202277)
- remove remove-pwscore.patch
* Mon Nov 28 2022 Zdenek Kubala <zkubala@suse.cz>
- enable build of cockpit-selinux module
- changes to keep it sync with sle micro
  (0002-selinux-temporary-remove-setroubleshoot-section.patch)
* Tue Sep 20 2022 Adam Majer <adam.majer@suse.de>
- new version 276.1
  - login: Use valid selectors when testing for :is() / :where() support.
  - stability and performance improvements
  - previous changes https://cockpit-project.org/blog/cockpit-275.html
- css-overrides.patch, hide-docs.patch, remove-pwscore.patch: refreshed
- kdump-close.patch, kdump-refactor.patch, kdump-suse.patch: upstreamed
  and removed
* Tue Sep 13 2022 Adam Majer <adam.majer@suse.de>
- Fix cockpit-storage dependencies
- Merge SUSE branding into cockpit package
* Mon Sep  5 2022 Jacek Tomasiak <jtomasiak@suse.com>
- Update kdump-suse.patch to match upstream.
* Wed Aug 24 2022 Jacek Tomasiak <jtomasiak@suse.com>
- Add kdump-close.patch required by patches below.
- Add kdump-refactor.patch and kdump-suse.patch to support SUSE
  kdump config management in cockpit.
* Wed Aug 24 2022 Adam Majer <adam.majer@suse.de>
- Use a list of available brandings to include in cockpit-ws
  package instead of resolving by symlinks.
* Thu Jul 28 2022 Jacek Tomasiak <jtomasiak@suse.com>
- Update suse-microos-branding.patch for new /etc/os-release ID.
- Add storage-btrfs.patch to enable BTRFS use in cockpit-storage.
* Thu Jun 23 2022 Adam Majer <adam.majer@suse.de>
- Add conflict between cockpit-networkmanager and cockpit-wicked
  as they use the same URL paths.
* Mon Jun 20 2022 Adam Majer <adam.majer@suse.de>
- Re-arrange patches and apply them manually again.
  Some were accidentally added and should be sle only
* Fri Jun 17 2022 Adam Majer <adam.majer@suse.de>
- css-overrides.patch: css overrides for better theming support
* Fri Jun 10 2022 Adam Majer <adam.majer@suse.de>
- new version 271
  https://cockpit-project.org/blog/cockpit-271.html
- cockpit-redhatfont.diff: not needed, dropped
- 0001-selinux-allow-login-to-read-motd-file.patch, hide-docs.patch,
  hide-pcp.patch remove-pwscore.patch: refreshed
* Fri Mar 18 2022 Jacek Tomasiak <jtomasiak@suse.com>
- re-add suse-microos-branding.patch from GitHub
- add hide-docs.patch (bsc#1197003)
* Tue Mar 15 2022 Jacek Tomasiak <jtomasiak@suse.com>
- make package compatible with OBS version (bsc#1197224):
  * move branding images to distribution-logos-SLE package
  * re-add dependency on distribution-logos
  * remove branding patch and assets (suse-microos-branding.patch,
    suse-microos-branding.tar.gz); moved to GitHub fork
  * remove local __python3 macro
  * apply SLE specific patches only on SLE
* Mon Feb 28 2022 Jacek Tomasiak <jtomasiak@suse.com>
- add hide-pcp.patch to hide references to PCP (Performance
  Co-Pilot) and metric collection (bsc#1195943). The cockpit-pcp
  package is not included in SLE Micro 5.2 base and these parts
  require it.
* Mon Jan 31 2022 Jacek Tomasiak <jtomasiak@suse.com>
- change self-signed cert group from cockpit-wsintance to
  cockpit-ws on upgrade
* Mon Jan 31 2022 Jacek Tomasiak <jtomasiak@suse.com>
- update to new LTS version from openSUSE:Factory
- port remove-pwscore.patch
  * remove dependency on pwscore (bsc#1182924)
  * remove password strenth indicator
- port branding changes as suse-microos "theme"
  * remove suse_cockpit_assets.tar.gz
  * add suse-microos-branding.tar.gz
  * remove branding_tests.patch
  * add suse-microos-branding.patch
- remove files not needed to build this version anymore
  * webpack-warnings-are-not-errors.patch
  * github_package.patch
  * nodejs_output_helper.bash
- remove cockpit.permissions workaround (bsc#1169614)
* Fri Jan 28 2022 Adam Majer <adam.majer@suse.de>
- new version 251.3
  * https://cockpit-project.org/blog/cockpit-251.html
  with additional fixes
  * Fix "Administrative Access" prompt for "Duo" MFA
* Thu Aug 19 2021 Ludwig Nussel <lnussel@suse.de>
- add --legacy-peer-deps to fix build
* Tue Aug  3 2021 Ludwig Nussel <lnussel@suse.de>
- new version 250
  https://cockpit-project.org/blog/cockpit-250.html
- fix pam_motd selinux denial (0001-selinux-allow-login-to-read-motd-file.patch)
* Thu May 27 2021 Adam Majer <adam.majer@suse.de>
- new version 245
  https://cockpit-project.org/blog/cockpit-245.html
* Tue May 18 2021 Ludwig Nussel <lnussel@suse.de>
- new version 244.1
  https://cockpit-project.org/blog/cockpit-244.html
- enable SELinux
* Mon May  3 2021 Ludwig Nussel <lnussel@suse.de>
- install all of pkg/lib in -devel package. Cockpit-machines needs more
* Fri Apr 30 2021 Ludwig Nussel <lnussel@suse.de>
- new version 243
  https://cockpit-project.org/blog/cockpit-243.html
  https://cockpit-project.org/blog/cockpit-242.html
  https://cockpit-project.org/blog/cockpit-241.html
  https://cockpit-project.org/blog/cockpit-240.html
  https://cockpit-project.org/blog/cockpit-239.html
* Wed Feb 24 2021 Adam Majer <adam.majer@suse.de>
- new version 238.1
  https://cockpit-project.org/blog/cockpit-238.html
  https://cockpit-project.org/blog/cockpit-237.html
- No longer recompress tarball at buildtime
* Thu Feb  4 2021 Ludwig Nussel <lnussel@suse.de>
- Rebuild from git leveraging local-npm-registry (needs
  cockpit-redhatfont.diff)
* Fri Jan 22 2021 Ludwig Nussel <lnussel@suse.de>
- new version 236
  https://cockpit-project.org/blog/cockpit-236.html
* Fri Jan 22 2021 Ludwig Nussel <lnussel@suse.de>
- new version 235
  https://cockpit-project.org/blog/cockpit-235.html
  https://cockpit-project.org/blog/cockpit-234.html
  https://cockpit-project.org/blog/cockpit-233.html
* Fri Nov 27 2020 Ludwig Nussel <lnussel@suse.de>
- new version 232
  https://cockpit-project.org/blog/cockpit-232.html
  https://cockpit-project.org/blog/cockpit-231.html
* Thu Oct 15 2020 Ludwig Nussel <lnussel@suse.de>
- new version 230
  https://cockpit-project.org/blog/cockpit-230.html
* Tue Oct  6 2020 Ludwig Nussel <lnussel@suse.de>
- new version 229
  https://cockpit-project.org/blog/cockpit-229.html
* Thu Oct  1 2020 Ludwig Nussel <lnussel@suse.de>
- new version 228
  https://cockpit-project.org/blog/cockpit-228.html
  https://cockpit-project.org/blog/cockpit-227.html
  https://cockpit-project.org/blog/cockpit-226.html
- enable cockpit-machines to manage libvirt
* Thu Sep 10 2020 Ludwig Nussel <lnussel@suse.de>
- adjust spec file to match upstream
* Fri Sep  4 2020 Thorsten Kukuk <kukuk@suse.com>
- cockpit-ws: don't require systemd (allows to build a very small
  cockpit-ws container)
* Mon Aug 31 2020 Ludwig Nussel <lnussel@suse.de>
- Add README.packaging for packagers
* Fri Aug 14 2020 Ludwig Nussel <lnussel@suse.de>
- new version 225:
  https://cockpit-project.org/blog/cockpit-223.html
  https://cockpit-project.org/blog/cockpit-224.html
  https://cockpit-project.org/blog/cockpit-225.html
* Wed Aug 12 2020 Thorsten Kukuk <kukuk@suse.com>
- Require group wheel
- Add permission macros [bsc#1169614]
- Create tmpfiles in %%post install
* Fri Jun 26 2020 Ludwig Nussel <lnussel@suse.de>
- new version 222:
  https://cockpit-project.org/blog/cockpit-222.html
  changelog from 221:
  https://cockpit-project.org/blog/cockpit-221.html
- enable docker module
* Tue Jun  9 2020 Ludwig Nussel <lnussel@suse.de>
- new version 220:
  https://cockpit-project.org/blog/cockpit-220.html
* Tue Jun  9 2020 Ludwig Nussel <lnussel@suse.de>
- disable selinux, sosreport and machines subpackages due to missing
  dependencies
* Wed Apr 29 2020 Ludwig Nussel <lnussel@suse.de>
- remove badness overrides to allow Factory submission
* Wed Apr 29 2020 Ludwig Nussel <lnussel@suse.de>
- remove branding with stale symlinks. Can't rely on /etc/os-release as OBS may
  use the dummy-release package.
* Tue Apr 28 2020 Ludwig Nussel <lnussel@suse.de>
- use pkgconfig(systemd) and pkgconfig(krb5)
- fix build with glib update (0001-bridge-Pass-connectable-to-TLS-client-connection.patch)
* Fri Mar 27 2020 Ludwig Nussel <lnussel@suse.de>
- new version 215
* Thu Aug 22 2019 Ludwig Nussel <lnussel@suse.de>
- new version 200
* Fri Jun 21 2019 Boris Manojlovic <boris@steki.net>
- updated to latest release 195
* Thu Mar  7 2019 Alex <aevseev@gmail.com>
- New upstream version - 189
* Mon Feb  4 2019 aevseev@gmail.com
- New upstream version - 186
* Wed Oct 24 2018 aevseev@gmail.com
- New upstream version - 180
* Fri Sep  7 2018 aevseev@gmail.com
- New upstream version - 177
* Mon Aug 27 2018 aevseev@gmail.com
- First build. Version - 176.
* Tue Oct 13 2015 kkaempf@suse.com
- Update to 0.79
  * Vagrant file for Cockpit development
  * Use libvirt for testing
  * Display only last lines of Kubernetes container logs
  See https://github.com/cockpit-project/cockpit/releases
- Add branding-symlinks.patch, SUSE doesn't carry Fedora pixmaps
* Sat Feb  7 2015 kkaempf@suse.com
- Initial release 0.38
